@@ -6,11 +6,6 @@ from typing import DefaultDict
 from typing import Tuple
 from typing import cast
 
-from ddtrace.internal.utils.deprecations import DDTraceDeprecationWarning
-
-from ..internal.utils.formats import get_env
-from ..vendor.debtcollector import deprecate
-
 
 def get_logger(name):
     # type: (str) -> DDLogger
@@ -92,8 +87,6 @@ class DDLogger(logging.Logger):
     log messages from within the ``ddtrace`` package.
     """
 
-    __slots__ = ("buckets", "rate_limit")
-
     # Named tuple used for keeping track of a log lines current time bucket and the number of log lines skipped
     LoggingBucket = collections.namedtuple("LoggingBucket", ("bucket", "skipped"))
 
@@ -111,16 +104,6 @@ class DDLogger(logging.Logger):
         # Allow configuring via `DD_TRACE_LOGGING_RATE`
         # DEV: `DD_TRACE_LOGGING_RATE=0` means to disable all rate limiting
         rate_limit = os.getenv("DD_TRACE_LOGGING_RATE", default=None)
-        if rate_limit is None:
-            # DEV: If not set, look at the deprecated (DD/DATADOG)_LOGGING_RATE_LIMIT
-            rate_limit = get_env("logging", "rate_limit")
-            if rate_limit is not None:
-                deprecate(
-                    "DD_LOGGING_RATE_LIMIT is deprecated",
-                    message="Use `DD_TRACE_LOGGING_RATE` instead",
-                    category=DDTraceDeprecationWarning,
-                    removal_version="1.0.0",
-                )
 
         if rate_limit is not None:
             self.rate_limit = int(rate_limit)
